#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-1bs5bMg2zSnDdKkEy4T7uF
key:                  ghcide-2.3.0.0-1bs5bMg2zSnDdKkEy4T7uF
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  7c2fd19b4c1457cf47e0ed3de2a2fd98
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-1bs5bMg2zSnDdKkEy4T7uF
depends:
    Diff-0.5-DaaQBhVKLTM3OHP5tNzqLY Glob-0.10.2-EYly3q4Jeez6q9Q1alwk2b
    aeson-2.2.1.0-LCgCxr5fZ2fF779OJkJoWg array-0.5.6.0
    async-2.2.5-4DIIy34WjVcL8AkZ9wmUb5 base-4.18.2.1
    base16-bytestring-1.0.2.0-G41qG77WeTiJP0VEPyRPnI binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8jGUMPhZyRG9nNczCrjpjo
    co-log-core-0.3.2.6-Hh0B9YJs2O69wRZEHl8awe containers-0.6.7
    cryptohash-sha1-0.11.101.0-A4nRRzinbNAGVNC9u6xRrl
    data-default-0.7.1.3-16enERVyZGuFmPxHvERcmd deepseq-1.4.8.1
    dependent-map-0.4.0.1-62tNqbPsuSELuUS7LTQVR7
    dependent-sum-0.7.2.0-JP0vMTLIraBJQMc0L0ufnB directory-1.3.8.5
    dlist-1.0-1TasFqTkWn5AeQgg6XTwXG
    enummapset-0.7.3.0-4WZKCrs5e3H5CrtycaWach exceptions-0.10.7
    extra-1.7.16-AfoBaNPhRbEFcSPAdLzWRD filepath-1.4.300.1
    fingertree-0.1.6.2-J9WM4SkClRhIlmI8lcYrtm
    focus-1.0.3.2-C3DMcI12egpGcXejJsxdJo ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-8zggGygC4HxIl8zeF9qb4
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-DA6doa2nkiFIeNm97rAg3i
    hashable-1.4.7.0-8DiXdwI1HyoGIpw8Heqw3G
    hie-bios-0.12.0-CDnscVdPbvs1C7R8FIcU8g
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-GiRA6zqNWLpYz1OQ01IZ4
    hls-graph-2.3.0.0-1auoKm6TpFS61Un6ycgUCL
    hls-plugin-api-2.3.0.0-8zybJu3GwnGGIEmRCHe9PV
    implicit-hie-0.1.4.0-4KvtSRS8dIafhbqnpoJsE
    implicit-hie-cradle-0.5.0.1-J9sCzkpPChd6fFTyewdigh
    lens-5.3.4-EMehBwckpg97FXX4cpVrvv
    list-t-1.0.5.7-CacaKZP76WB63bp0x1EyI8
    lsp-2.2.0.0-9EJoWIhD6rI2D8tpdtw5RF
    lsp-types-2.0.2.0-HgpVsxXVwzUAL0UBBsxEKQ mtl-2.3.1
    opentelemetry-0.8.0-B4jz8NhOlBqHahO6ZN0xdJ
    optparse-applicative-0.18.1.0-5rdJae4Jo9sKWG5YERkeVE
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-eZs6LtbK8M8wXnTmHvu32
    prettyprinter-ansi-terminal-1.1.3-8KMwVKd8YM3Hu4h7aLdV2z
    random-1.2.1.3-6vcHOvK2uEB1wXqnxBIn5Y
    regex-tdfa-1.3.2.5-5bDru6fij8SGfwt7jz3tue
    row-types-1.0.1.2-L0uu6x7HHtJ9wcPcmwl03Z
    safe-exceptions-0.1.7.4-BNBHk4dGlb5HruviKsCZ9o
    sorted-list-0.2.3.1-3eRJU7Chi1e1t3NxcmBdBR
    sqlite-simple-0.4.19.0-IUaj5TD3kxu7KlxnVJqPDL stm-2.5.1.0
    stm-containers-1.2.1.1-CPYUXoByhl1GpcJraNZFj7
    syb-0.7.3-K9V4mFAbfAKIQTGSYawcKu text-2.0.2
    text-rope-0.3-D8FYpvSLMW4FffQJOlPBxU time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-9Z9EbXnVp5r8OKFytY6XZD
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-LFprVvrjTX4JVFniJRp7e6
    vector-0.13.2.0-KR0oqssWe4cgn21CCdckk

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

